==> 0.1.37.tar.gz: android/src/main/java/com/medipreco/loopboxplugin/LoopboxpluginPlugin.java <==
package com.medipreco.loopboxplugin;

import android.content.Context;
import android.util.Log;
import br.com.loopkey.indigo.lklib.LKLib;
import br.com.loopkey.indigo.lklib.LKMainThreadImpl;
import br.com.loopkey.indigo.lklib.core.LKReachableDevice;
import br.com.loopkey.indigo.lklib.core.LKReachableDeviceImpl;
import br.com.loopkey.indigo.lklib.core.LKReachableDeviceListener;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** LoopboxpluginPlugin */
public class LoopboxpluginPlugin implements FlutterPlugin, MethodCallHandler {

  private LKReachableDevice reachableDevice;
  private LKReachableDeviceListener reachableDeviceListener;
  private Context context;
  private LoopboxEventHandler loopboxEventHandler;

  public LoopboxpluginPlugin() {
    reachableDevice = LKReachableDeviceImpl.newInstance();
  }

  @Override
  public void onAttachedToEngine(FlutterPluginBinding flutterPluginBinding) {
    final MethodChannel channel = new MethodChannel(
        flutterPluginBinding.getFlutterEngine().getDartExecutor(),
        "loopboxplugin");
    channel.setMethodCallHandler(new LoopboxpluginPlugin());
    this.context = flutterPluginBinding.getApplicationContext();
    LKLib.install(this.context, new LKMainThreadImpl());

    this.loopboxEventHandler = new LoopboxEventHandler(flutterPluginBinding.getBinaryMessenger());
    this.loopboxEventHandler.setupEventChannels();
  }

  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "loopboxplugin");
    channel.setMethodCallHandler(new LoopboxpluginPlugin());
  }

  @Override
  public void onMethodCall(MethodCall call, Result result) {
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);
      Log.d("LoopboxP", "Valor LoopboxEvent " + this.loopboxEventHandler);

//      this.loopboxEventHandler.sendMessage("Mensagem em onAttachedToEngine");
    } else if (call.method.equals("startListeningNearbyDevices")) {
      this.startListeningNearbyDevices();
      Log.d("LoopboxP", "Listening for nearby devices...");
      result.success("Listening for nearby devices...");
    } else if (call.method.equals("openLock")) {
      UnlockData unlockData = new UnlockData(
        call.argument("id") + "",
        call.argument("kind") + "",
        call.argument("key") + "",
        call.argument("commandData") + ""
      );

      this.openLock(unlockData);
      Log.d("LoopboxP", "Opening port...");
      result.success("Abrindo a porta...");

    } else {
      result.notImplemented();
    }
  }

  private void startListeningNearbyDevices() {
    this.reachableDeviceListener = new ReachableDeviceListener();
    reachableDevice.subscribe(this.reachableDeviceListener);
  }

  private void openLock(UnlockData unlockData) {
    LKReachableDeviceListener unlockerListener =
        new ReachableDeviceUnlockerListener(reachableDevice, unlockData);
    reachableDevice.subscribe(unlockerListener);
  }

  @Override
  public void onDetachedFromEngine(FlutterPluginBinding binding) {
  }
}

==> 0.1.38.tar.gz: android/src/main/java/com/medipreco/loopboxplugin/LoopboxpluginPlugin.java <==
package com.medipreco.loopboxplugin;

import android.content.Context;
import android.util.Log;
import br.com.loopkey.indigo.lklib.LKLib;
import br.com.loopkey.indigo.lklib.LKMainThreadImpl;
import br.com.loopkey.indigo.lklib.core.LKReachableDevice;
import br.com.loopkey.indigo.lklib.core.LKReachableDeviceImpl;
import br.com.loopkey.indigo.lklib.core.LKReachableDeviceListener;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** LoopboxpluginPlugin */
public class LoopboxpluginPlugin implements FlutterPlugin, MethodCallHandler {

  private LKReachableDevice reachableDevice;
  private LKReachableDeviceListener reachableDeviceListener;
  private Context context;
  private LoopboxEventHandler loopboxEventHandler;

  public LoopboxpluginPlugin() {
    reachableDevice = LKReachableDeviceImpl.newInstance();
  }

  @Override
  public void onAttachedToEngine(FlutterPluginBinding flutterPluginBinding) {
    final MethodChannel channel = new MethodChannel(
        flutterPluginBinding.getFlutterEngine().getDartExecutor(),
        "loopboxplugin");
    channel.setMethodCallHandler(new LoopboxpluginPlugin());
    this.context = flutterPluginBinding.getApplicationContext();
    LKLib.install(this.context, new LKMainThreadImpl());

//    this.loopboxEventHandler = new LoopboxEventHandler(flutterPluginBinding.getBinaryMessenger());
//    this.loopboxEventHandler.setupEventChannels();
  }

  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "loopboxplugin");
    channel.setMethodCallHandler(new LoopboxpluginPlugin());

    LoopboxEventHandler loopboxEventHandler = new LoopboxEventHandler(registrar.messenger());
    loopboxEventHandler.setupEventChannels();
  }

  @Override
  public void onMethodCall(MethodCall call, Result result) {
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);
      Log.d("LoopboxP", "Valor LoopboxEvent " + this.loopboxEventHandler);

//      this.loopboxEventHandler.sendMessage("Mensagem em onAttachedToEngine");
    } else if (call.method.equals("startListeningNearbyDevices")) {
      this.startListeningNearbyDevices();
      Log.d("LoopboxP", "Listening for nearby devices...");
      result.success("Listening for nearby devices...");
    } else if (call.method.equals("openLock")) {
      UnlockData unlockData = new UnlockData(
        call.argument("id") + "",
        call.argument("kind") + "",
        call.argument("key") + "",
        call.argument("commandData") + ""
      );

      this.openLock(unlockData);
      Log.d("LoopboxP", "Opening port...");
      result.success("Abrindo a porta...");

    } else {
      result.notImplemented();
    }
  }

  private void startListeningNearbyDevices() {
    this.reachableDeviceListener = new ReachableDeviceListener();
    reachableDevice.subscribe(this.reachableDeviceListener);
  }

  private void openLock(UnlockData unlockData) {
    LKReachableDeviceListener unlockerListener =
        new ReachableDeviceUnlockerListener(reachableDevice, unlockData);
    reachableDevice.subscribe(unlockerListener);
  }

  @Override
  public void onDetachedFromEngine(FlutterPluginBinding binding) {
  }
}
